==> mstflint-4.28.0-1.tar.gz: mstflint-4.28.0/mlxdpa/hostelf.h <==
/*
 * Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. ALL RIGHTS RESERVED.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef MLXDPA_HOSTELF_H_
#define MLXDPA_HOSTELF_H_

#include <string>
#include <vector>
#include <dpa_elf/dpa_elf.h>

using namespace std;

class HostElf
{
public:
    HostElf(string path, string outputPath);

    vector<AppHandle*> GetListOfDpaApps();
    vector<u_int8_t> GetDpaApp(const AppHandle& app);
    void AddSection(string sectionName, const vector<u_int8_t>& section);
    void RemoveSection(string sectionName);

private:
    string _filePath;
    string _outputPath;
    vector<u_int8_t> _data;
    AppTable _dpaAppsTable;
};

#endif /* MLXDPA_HOSTELF_H_ */

==> mstflint-4.32.0-1.tar.gz: mstflint-4.32.0/mlxdpa/hostelf.h <==
/*
 * Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. ALL RIGHTS RESERVED.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef MLXDPA_HOSTELF_H_
#define MLXDPA_HOSTELF_H_

#include <string>
#include <vector>
#include <dpa_elf/dpa_elf.h>

using namespace std;

class HostElf
{
public:
    HostElf(string path, string outputPath);
    ~HostElf();

    vector<AppHandle*> GetListOfDpaApps();
    vector<DevObjHandle*> GetListOfDpaArchApps(DevObjHandle* objTable, uint64_t arch_count);
    vector<u_int8_t> GetDpaApp(const DevObjHandle& app);
    void AddSection(string sectionName, const vector<u_int8_t>& section);
    void RemoveSection(string sectionName);

private:
    string _filePath;
    string _outputPath;
    vector<u_int8_t> _data;
    AppTable _dpaAppsTable;
};

#endif /* MLXDPA_HOSTELF_H_ */
